@@ -15,15 +15,15 @@ sys.modules['matrix'] = argument_esa_model.matrix
 class ESA:
     def __init__(self, matrix_path, model_path, vocab_path = None, similarity = "cos"):
         self._pre = Preprocessor(vocab_path)
-        self._mat = pickle.load(open(matrix_path, "rb"))
-        self._mat_2= self._mat.get_mat().transpose().todense()
+        self._esa_model = pickle.load(open(matrix_path, "rb"))
+        self._mat= self._esa_model.get_mat().transpose().todense()
         self.index_map = {}
-        for term in self._mat.get_terms():
-            self.index_map[term]=self._mat.get_terms().index(term)
+        for term in self._esa_model.get_terms():
+            self.index_map[term]=self._esa_model.get_terms().index(term)
         self._sim = similarity
-        self._model = None
+        self.word2vec_model = None
         if similarity != "cos":
-            self._model = gensim.models.keyedvectors.KeyedVectors.load_word2vec_format(model_path, binary = True)
+            self.word2vec_model = gensim.models.keyedvectors.KeyedVectors.load_word2vec_format(model_path, binary = True)
 
     def _to_vector(self, document, lemma):
         if lemma:
@@ -38,21 +38,15 @@ class ESA:
             vec.eliminate_zeros()
             return vec, terms_document
         else:
-            start = time.time()
             bow = self._pre.to_bow(document, lemma)
-            end = time.time()
-            print("tokenizing time is %d"%(end - start))
             terms_document = tuple(bow.keys())
             length = sum(bow.values())
-            vec = sparse.lil_matrix(np.zeros((len(self._mat.get_terms()), 1), dtype = np.longdouble))
-            start = time.time()
-            for term in self._mat.get_terms():
+            vec = sparse.lil_matrix(np.zeros((len(self._esa_model.get_terms()), 1), dtype = np.longdouble))
+            for term in self._esa_model.get_terms():
                 try:
                     vec[self.index_map[term], 0] = bow[term] / length
                 except:
                     vec[self.index_map[term], 0] = 0.0
-            end = time.time()
-            print("tf calculating is %d"%(end - start))
             vec = sparse.csc_matrix(vec)
             vec.eliminate_zeros()
             return vec, terms_document
@@ -70,24 +64,17 @@ class ESA:
         lemma = False
         if self._sim != "cos":
             lemma = True
-
-        start = time.time()
         document_vec, terms_document = self._to_vector(document, lemma)
-        end = time.time()
-        print("processing time is %d"%(end - start))
         result = {}
 
         if self._sim == "cos":
-            start = time.time()
-            result_vector= Similarity.cosine_similarity(document_vec, self._mat_2)
-            end = time.time()
-            print("similarity calculating time is %d"%(end - start))
-            for i,concept in enumerate(self._mat.get_concepts()):
+            result_vector= Similarity.cosine_similarity(document_vec, self._mat)
+            for i,concept in enumerate(self._esa_model.get_concepts()):
                 result[concept] = result_vector[i]
 
         elif self._sim == "max":
-            for concept in self._mat.get_concepts():
-                res = Similarity.maximum_matching_similarity(self._model, document_vec, self._mat[concept], terms_document, self._mat._terms)
+            for concept in self._esa_model.get_concepts():
+                res = Similarity.maximum_matching_similarity(self.word2vec_model, document_vec, self._esa_model[concept], terms_document, self._esa_model._terms)
                 result[concept] = res
         elif self._sim == "avg":
                 raise NotImplementedError
